@@ -40,5 +40,12 @@ __all__ = [
     'facial_beauty_short',
     'watermark_image_enhance',
     'foreign_matter_removal',
-    'sh_face_enhancement'
+    'sh_face_enhancement',
+    'portrait_style_pipeline',
+    'swap_face',
+    'clear_noise',
+    'supper_resolution',
+    'font_generation',
+    'replace_hair',
+    'cartoon_portrait'
 ]
