@@ -11,7 +11,7 @@ import logging
 
 class AuthInfo(object):
 
-    def __init__(self, host, user_name, password, extranet=False, gateway_cache=True, random_name=False):
+    def __init__(self, host, user_name, password, extranet=False, gateway_cache=True, random_name=False, **kwargs):
         """
         账号验证
         :param host:服务器地址 例如:http://gateway.algo.leqi.us
@@ -35,6 +35,7 @@ class AuthInfo(object):
 
         if random_name:
             logging.warning('AuthInfo 除非你有特殊需求 否则请保持 random_name=False 这会可以避免文件的重复上传')
+        self.kwargs = kwargs
 
 
 class ClassicAuthInfo(AuthInfo):
