@@ -192,12 +192,14 @@ class AlgoBase(Base):
     各个算法的基类,通过继承此模块,拥有生成算法参数,请求算法等功能
     """
     __algo_name__ = None
+    DEFAULT_TIMEOUT = 30  # 默认的超时时长
 
     def __init__(self, auth_info: AuthInfo):
         super().__init__(auth_info)
         self.algo_name = self.__algo_name__
         self.gateway_cache = auth_info.gateway_cache
         self.request = {}
+        self.gateway_params = {}
 
     def init_request(self):
         """
@@ -232,7 +234,10 @@ class AlgoBase(Base):
                 'password': self._password,
                 'target': self.algo_name,
                 'gateway_cache': self.gateway_cache,
-                'request': self.request}
+                'request': self.request,
+                **self._auth_info.kwargs,
+                **self.gateway_params
+                }
         if self._has_classic:
             data['classic_user_name'] = self._auth_info.classic_user_name
             data['classic_password'] = self._auth_info.classic_password
@@ -254,13 +259,14 @@ class AlgoBase(Base):
                 yield _interval[-1]
             i += 1
 
-    def synchronous_request(self, timeout=30, interval=0.5):
+    def synchronous_request(self, timeout=None, interval=0.5):
         """
         同步请求算法(实质上是多次异步请求)
         :param timeout:请求超时时间
         :param interval: 每次轮询的间隔,可以为数值,也可以为list[int],即每次轮询的间隔
         :return:algorithm.response.Response
         """
+        timeout = timeout or self.DEFAULT_TIMEOUT
         stop_time = time.time() + timeout
         # 发布任务
         task_id = self.asynchronous_request().task_id
